float4x4 matWorld;
float4x4 matWorldViewProj;
float4 vecViewPos;
float4 vecSunDir;

texture terrsand_bmap;
texture terrfels_bmap;
texture terrgras_bmap;

sampler2D smpSand = sampler_state
{
	Texture = <terrsand_bmap>;
	
	MinFilter	= linear;
	MagFilter	= linear;
	MipFilter	= linear;
	
	AddressU		= Wrap;
	AddressV		= Wrap;
};

sampler2D smpFels = sampler_state
{
	Texture = <terrfels_bmap>;
	
	MinFilter	= linear;
	MagFilter	= linear;
	MipFilter	= linear;
	
	AddressU		= Wrap;
	AddressV		= Wrap;
};

sampler2D smpGras = sampler_state
{
	Texture = <terrgras_bmap>;
	
	MinFilter	= linear;
	MagFilter	= linear;
	MipFilter	= linear;
	
	AddressU		= Wrap;
	AddressV		= Wrap;
};

struct VS_OUT
{
	float4 Pos : POSITION;
	float2 Tex : TEXCOORD0;
	float4 WorldPos : TEXCOORD1;
	float3 Normal : TEXCOORD2;
};

VS_OUT Shader_VS(float4 inPos : POSITION, float2 inTex : TEXCOORD0, float3 inNormal : NORMAL)
{
	VS_OUT Out = (VS_OUT)0;
	
	Out.Pos = mul(inPos, matWorldViewProj);
	
	Out.Tex = inTex;
	Out.WorldPos = mul(inPos, matWorld);
	Out.Normal = mul(inNormal, matWorld);
	Out.Normal = normalize(Out.Normal);
	
	return Out;
}

float4 Shader_PS(float2 inTex : TEXCOORD0, float4 inPos : TEXCOORD1, float3 inNormal : TEXCOORD2) : COLOR
{
	float4 Color;
	
	float4 sand = tex2D(smpSand, inTex*10);
	float4 fels = tex2D(smpFels, inTex*10);
	float4 gras = tex2D(smpGras, inTex*10);
	
	float ambient = 0.5;
	float diffuse = dot(vecSunDir, inNormal)*0.5+0.5;
	float shading = ambient+diffuse;
	
	Color = lerp(gras, sand, saturate((0-inPos.y)*0.03));
	Color = lerp(fels, Color, saturate(pow(inNormal.y*1.5, 4)-0.3));
	
	Color *= shading;
	
	Color.a = 1.0;
	
	return Color;
}

technique tech_00
{
	pass pass_00
	{
		VertexShader = compile vs_2_0 Shader_VS();
		PixelShader = compile ps_2_0 Shader_PS();
	}
}
